@@ -1,9 +1,14 @@
+from typing import TYPE_CHECKING
+
+if TYPE_CHECKING:
+    from ..browser import Browser
+
+
 class LibraryComponent:
-    def __init__(self, library):
+    def __init__(self, library: "Browser") -> None:
         """Base class exposing attributes from the common context.
 
         :param library: The library itself as a context object.
-        :type library: Browser.Browser
         """
         self.library = library
 
