@@ -1,15 +1,19 @@
 from .browser_control import Control
+from .cookie import Cookie
+from .device_descriptors import Devices
 from .evaluation import Evaluation
-from .playwright_state import PlaywrightState
 from .getters import Getters
 from .interaction import Interaction
 from .network import Network
+from .playwright_state import PlaywrightState
 from .promises import Promises
 from .waiter import Waiter
 from .webapp_state import WebAppState
 
 __all__ = [
     "Control",
+    "Cookie",
+    "Devices",
     "Getters",
     "Evaluation",
     "Interaction",
