@@ -88,3 +88,34 @@ class Waiter(LibraryComponent):
                 )
             )
             logger.info(response.log)
+
+    @keyword(tags=["Wait"])
+    def wait_for_download(self):
+        """ Waits for next download event on page. Returns file path to downloaded file.
+
+            To enable downloads context's ``acceptDownloads`` needs to be true.
+
+            Downloaded files are deleted when Context the download happened in is closed.
+
+            | New Context    | acceptDownloads=True
+            | New Page       | ${LOGIN_URL}
+            | ${dl_promise}  | Promise To  Wait For Download
+            | Click          | \\#file_download
+            | ${file_path}=  | Wait For  ${dl_promise}
+        """
+        # TODO: replace with argument saveAs: str ="" in function signature after PW 1.3
+        # TODO: add to docstring along with above change WIP: Will only work with playwright > 1.3 ``saveAs`` override filename to save as.
+        saveAs = None
+        with self.playwright.grpc_channel() as stub:
+            from pathlib import Path
+
+            if not saveAs:
+                response = stub.WaitForDownload(Request().FilePath())
+                logger.debug(response.log)
+                return json.loads(response.body)
+            else:
+                p = Path(saveAs)
+                p.resolve()
+                response = stub.WaitForDownload(Request().FilePath(path=str(p)))
+                logger.debug(response.log)
+                return json.loads(response.body)
