@@ -2,6 +2,13 @@ from enum import Enum, auto
 from typing import TypedDict
 
 
+class CookieType(Enum):
+    dictionary = "dict"
+    dict = "dict"
+    string = "string"
+    str = "str"
+
+
 class RequestMethod(Enum):
     HEAD = auto()
     GET = auto()
@@ -42,6 +49,20 @@ ColorScheme = Enum("ColorScheme", ["dark", "light", "no-preference"])
 ViewportDimensions = TypedDict("ViewportDimensions", {"width": int, "height": int})
 
 
+class BoundingBoxFields(Enum):
+    width = "width"
+    height = "height"
+    x = "x"
+    y = "y"
+    ALL = "ALL"
+
+
+class AutoClosingLevel(Enum):
+    SUITE = auto()
+    TEST = auto()
+    MANUAL = auto()
+
+
 class ElementState(Enum):
     attached = auto()
     detached = auto()
